==> joda_1.0.0.tgz: joda/doc/JodaVignette.R <==
###################################################
### chunk number 1: options
###################################################
#line 34 "JodaVignette.Rnw"
options(width=70)


###################################################
### chunk number 2: preliminaries
###################################################
#line 56 "JodaVignette.Rnw"
library(joda)
data(damage)


###################################################
### chunk number 3: 
###################################################
#line 64 "JodaVignette.Rnw"
head(data.healthy)
head(data.damage)


###################################################
### chunk number 4: 
###################################################
#line 74 "JodaVignette.Rnw"
print(model.healthy)
print(model.damage)


###################################################
### chunk number 5: 
###################################################
#line 84 "JodaVignette.Rnw"
str(beliefs.healthy)
str(beliefs.damage)
head(beliefs.healthy[["p53"]])


###################################################
### chunk number 6: 
###################################################
#line 112 "JodaVignette.Rnw"
probs.healthy=differential.probs(data=data.healthy, beliefs=beliefs.healthy, verbose=TRUE, plot.it=TRUE)


###################################################
### chunk number 7: fig-healthyM
###################################################
#line 127 "JodaVignette.Rnw"
probs.healthy=differential.probs(data=data.healthy, beliefs=beliefs.healthy, verbose=FALSE, plot.it=TRUE)


###################################################
### chunk number 8: 
###################################################
#line 136 "JodaVignette.Rnw"
probs.damage=differential.probs(data=data.damage, beliefs=beliefs.damage, verbose=TRUE, plot.it=TRUE)


###################################################
### chunk number 9: fig-damageM
###################################################
#line 149 "JodaVignette.Rnw"
probs.damage=differential.probs(data=data.damage, beliefs=beliefs.damage, verbose=FALSE, plot.it=TRUE)


###################################################
### chunk number 10: 
###################################################
#line 166 "JodaVignette.Rnw"
regulation.healthy= regulation.scores(probs.healthy, model.healthy, TRUE) 
head(regulation.healthy) 
regulation.damage= regulation.scores(probs.damage, model.damage, TRUE) 
head(regulation.damage) 


###################################################
### chunk number 11: 
###################################################
#line 178 "JodaVignette.Rnw"
deregulation= deregulation.scores(reg.scores1=regulation.healthy, reg.scores2=regulation.damage, TRUE) 
head(deregulation)


###################################################
### chunk number 12: 
###################################################
#line 187 "JodaVignette.Rnw"
head(rownames(deregulation)[order(deregulation[,"p53"])])

==> joda_1.2.0.tgz: joda/doc/JodaVignette.R <==
### R code from vignette source 'JodaVignette.Rnw'

###################################################
### code chunk number 1: options
###################################################
options(width=70)


###################################################
### code chunk number 2: preliminaries
###################################################
library(joda)
data(damage)


###################################################
### code chunk number 3: JodaVignette.Rnw:63-65
###################################################
head(data.healthy)
head(data.damage)


###################################################
### code chunk number 4: JodaVignette.Rnw:73-75
###################################################
print(model.healthy)
print(model.damage)


###################################################
### code chunk number 5: JodaVignette.Rnw:83-86
###################################################
str(beliefs.healthy)
str(beliefs.damage)
head(beliefs.healthy[["p53"]])


###################################################
### code chunk number 6: JodaVignette.Rnw:111-112
###################################################
probs.healthy=differential.probs(data=data.healthy, beliefs=beliefs.healthy, verbose=TRUE, plot.it=TRUE)


###################################################
### code chunk number 7: fig-healthyM
###################################################
probs.healthy=differential.probs(data=data.healthy, beliefs=beliefs.healthy, verbose=FALSE, plot.it=TRUE)


###################################################
### code chunk number 8: JodaVignette.Rnw:135-136
###################################################
probs.damage=differential.probs(data=data.damage, beliefs=beliefs.damage, verbose=TRUE, plot.it=TRUE)


###################################################
### code chunk number 9: fig-damageM
###################################################
probs.damage=differential.probs(data=data.damage, beliefs=beliefs.damage, verbose=FALSE, plot.it=TRUE)


###################################################
### code chunk number 10: JodaVignette.Rnw:165-169
###################################################
regulation.healthy= regulation.scores(probs.healthy, model.healthy, TRUE) 
head(regulation.healthy) 
regulation.damage= regulation.scores(probs.damage, model.damage, TRUE) 
head(regulation.damage) 


###################################################
### code chunk number 11: JodaVignette.Rnw:177-179
###################################################
deregulation= deregulation.scores(reg.scores1=regulation.healthy, reg.scores2=regulation.damage, TRUE) 
head(deregulation)


###################################################
### code chunk number 12: JodaVignette.Rnw:186-187
###################################################
head(rownames(deregulation)[order(deregulation[,"p53"])])
